@@ -1,6 +1,7 @@
 from dataclasses import dataclass
 from os import mkdir
 from os.path import exists
+from time import sleep
 
 from requests import get
 from requests.exceptions import ConnectionError
@@ -22,15 +23,16 @@ class ExploitInfo:
     Link: str
 
 
-def GetExploitInfo(CVEID, log) -> list:
+def GetExploitInfo(CVEID, log) -> list[ExploitInfo]:
+    sleep(0.75)
     try:
-        apiresponse = get(
+        apidata = get(
             f"https://www.exploit-db.com/search?cve={CVEID}",
             headers={
                 "X-Requested-With": "XMLHttpRequest",
                 "User-Agent": next(random_user_agent(log)),
             },
-        )
+        ).json()
     except ConnectionError:
         log.logger(
             "error",
@@ -38,12 +40,10 @@ def GetExploitInfo(CVEID, log) -> list:
             + f" to fetch information about: {CVEID}",
         )
         return []
+    except Exception as e:
+        log.logger("error", f"An error occured while parsing API response.")
+        return []
     else:
-        try:
-            apidata = apiresponse.json()
-        except Exception as e:
-            log.logger("error", f"An error occured while parsing API response.")
-            return []
         ExploitInfos = []
         for exploit in apidata["data"]:
             Exploit = ExploitInfo(
@@ -61,7 +61,8 @@ def GetExploitInfo(CVEID, log) -> list:
         return ExploitInfos
 
 
-def GetExploitContents(ExploitLink, log):
+def GetExploitContents(ExploitLink, log) -> tuple:
+    sleep(0.75)
     user_agent = next(random_user_agent(log))
     try:
         apiresponse = get(
