@@ -139,7 +139,7 @@ def PortScan(
         return nm
 
 
-def CreateNoise(target):
+def CreateNoise(target) -> None:
     nm = PortScanner()
     while True:
         try:
@@ -194,14 +194,15 @@ def DiscoverHosts(target, console, scantype=ScanType.ARP, mode=ScanMode.Normal)
     else:
         banner(f"Scanning {target} using {scantype.name} scan ...", "green", console)
 
-    OnlineHosts = TestPing(target, mode)
     if scantype == ScanType.ARP:
         OnlineHosts = TestArp(target, mode)
+    else:
+        OnlineHosts = TestPing(target, mode)
 
     return OnlineHosts
 
 
-def InitHostInfo(target_key):
+def InitHostInfo(target_key) -> TargetInfo:
     try:
         mac = target_key["addresses"]["mac"]
     except (KeyError, IndexError):
@@ -236,7 +237,7 @@ def InitHostInfo(target_key):
     )
 
 
-def InitPortInfo(port):
+def InitPortInfo(port) -> tuple[str, str, str, str]:
     state = "Unknown"
     service = "Unknown"
     product = "Unknown"
