@@ -1,5 +1,7 @@
 from modules.logger import banner
+from modules.random_user_agent import random_user_agent
 from modules.web.crawler import crawl
+from modules.web.dirbust import dirbust
 from modules.web.lfi import TestLFI
 from modules.web.sqli import TestSQLI
 from modules.web.xss import TestXSS
@@ -19,18 +21,15 @@ def webvuln(target, log, console) -> None:
         """
         Get the target url
         """
-
-        url_ = [f"http://{target}", f"https://{target}"]
+        headers = {"User-Agent": next(random_user_agent(log))}
+        url_ = [f"http://{target}/", f"https://{target}/"]
         for url in url_:
-            for _ in range(3): # do 3 tries
-                try:
-                    get(url, timeout=10)
-                except Exception as e:
-                    continue
-                else:
-                    return url
-
-        return None
+            try:
+                get(url, headers=headers, timeout=10)
+            except Exception as e:
+                return None
+            else:
+                return url
 
     target_url = get_url(target)
 
@@ -46,13 +45,14 @@ def webvuln(target, log, console) -> None:
     log.logger("info", f"Found {len(testable_urls)} testable urls.")
 
     if len(testable_urls) == 0:
-        log.logger("warning","No testable urls found for current host.")
         return
 
     banner(f"Testing web application on {target} ...", "purple", console)
 
+    dirbust(target_url, console, log)
+
     for url in testable_urls:
         LFI.test_lfi(url)
         SQLI.test_sqli(url)
         XSS.test_xss(url)
-        tested_urls.append(url)
\ No newline at end of file
+        tested_urls.append(url)
